require 'minitest/byebug' if ENV['DEBUG']
require 'minitest/autorun'
require 'gared'

class GaredTest < Minitest::Test

  def test_nli_api_query_publicatios_by_person
    if ENV['NLI_API_KEY'].nil?
      puts "skipping NLI API test because NLI_API_KEY envvar is not set"
      return
    end
    puts "Testing NLI API"
    nli = Gared::Nli_Api.new('https://api.nli.org.il/openlibrary/search', ENV['NLI_API_KEY'])
    refute_nil nli
    recs = nli.query_publications_by_person('ביאליק')
    #recs = nli.query_publications_by_person('אילנאה')
    refute_nil recs
    refute_empty(recs)
    refute_empty(recs[0].title)
  end

  def test_primo_query_publicatios_by_person
    puts "Testing Primo"
    primo = Gared::Primo.new('http://primo.nli.org.il/PrimoWebServices/xservice/search/brief', 'NNL')
    refute_nil primo
    recs = primo.query_publications_by_person('אילנאה')
    refute_nil recs
    refute_empty(recs)
    refute_empty(recs[0].title)
  end

  def test_aleph_query_publicatios_by_person
    puts "Testing Aleph"
    aleph = Gared::Aleph.new('aleph.nli.org.il', 9991, 'NNL01')
    refute_nil aleph
    recs = aleph.query_publications_by_person('אילנאה')
    refute_nil recs
    refute_empty(recs)
    refute_empty(recs[0].title)
  end

  def test_googlebooks_query_publicatios_by_person
    puts "Testing Google Books"
    gb = Gared::Googlebooks.new('AIzaSyCE2WFqTPdxAz1wv2f33hMfPWIF4tcocgM') # a key I made just for testing this gem. Please do not abuse.
    refute_nil gb
    recs = gb.query_publications_by_person('מנדלי')
    refute_nil recs
    refute_empty(recs)
    refute_empty(recs[0].title)
  end

  def test_hebrewbooks_query_publicatios_by_person
    skip("Skipping testing Hebrewbooks because chromedriver not found") unless `chromedriver -v` =~ /ChromeDriver/
    puts "Testing Hebrewbooks"
    hb = Gared::Hebrewbooks.new
    refute_nil hb
    recs = hb.query_publications_by_person('שיין')
    refute_nil recs
    refute_empty(recs)
    refute_empty(recs[0].title)
  end

  def test_idea_query_publicatios_by_person
    skip("Skipping testing IDEA because chromedriver not found") unless `chromedriver -v` =~ /ChromeDriver/
    puts "Testing IDEA"
    idea = Gared::Idea.new('http://infocenters.co.il/RAANANA/')
    refute_nil idea
    recs = idea.query_publications_by_person('גפלה, אופיר')
    refute_nil recs
    refute_empty(recs)
    refute_empty(recs[0].title)
    recs = idea.query_publications_by_person('אילנאהסןסן') # nonsense
    refute_nil recs
    assert_empty(recs)
  end

end